@@ -61,7 +61,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 #endif
     KLocalizedString::setApplicationDomain("calindori");
 
-    KAboutData aboutData(QStringLiteral("calindori"), i18n("Calindori"), QStringLiteral(CALINDORI_VERSION_STRING), i18nc("@title", "Calendar application"), KAboutLicense::GPL_V3, i18nc("@info:credit", "(c) 2018-2021 The Calindori Team"));
+    KAboutData aboutData(QStringLiteral("calindori"), i18n("Calindori"), QStringLiteral(CALINDORI_VERSION_STRING), i18nc("@title", "Calendar application"), KAboutLicense::GPL_V3, i18nc("@info:credit", "(c) 2018-2022 The Calindori Team"));
 
     aboutData.setOrganizationDomain(QByteArray("kde.org"));
     aboutData.setProductName(QByteArray("calindori"));
@@ -69,6 +69,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     aboutData.addAuthor(i18nc("@info:credit", "Dimitris Kardarakos"), i18nc("@info:credit", "Developer"), QStringLiteral("dimkard@posteo.net"));
 
     aboutData.addAuthor(i18nc("@info:credit", "Nicolas Fella"), i18nc("@info:credit", "Developer"), QStringLiteral("nicolas.fella@gmx.de"));
+    
+    aboutData.addAuthor(i18nc("@info:credit", "Devin Lin"), i18nc("@info:credit", "Developer"), QStringLiteral("devin@kde.org"));
 
     aboutData.setHomepage(QStringLiteral("https://invent.kde.org/kde/calindori"));
 
@@ -88,7 +90,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QGuiApplication::setOrganizationDomain(aboutData.organizationDomain());
     QGuiApplication::setApplicationVersion(aboutData.version());
 
-    qmlRegisterType<CalindoriConfig>("org.kde.calindori", 0, 1, "CalindoriConfig");
     qmlRegisterType<LocalCalendar>("org.kde.calindori", 0, 1, "LocalCalendar");
     qmlRegisterType<IncidenceAlarmsModel>("org.kde.calindori", 0, 1, "IncidenceAlarmsModel");
     qmlRegisterType<DaysOfMonthModel>("org.kde.calindori", 0, 1, "DaysOfMonthModel");
@@ -96,8 +97,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterType<DaysOfMonthIncidenceModel>("org.kde.calindori", 0, 1, "DaysOfMonthIncidenceModel");
     qmlRegisterType<IncidenceModel>("org.kde.calindori", 0, 1, "IncidenceModel");
     qmlRegisterType<AttendeesModel>("org.kde.calindori", 0, 1, "AttendeesModel");
-    qmlRegisterUncreatableType<KCalendarCore::Incidence>("org.kde.calindori", 0, 1, "CalendarIncidence", "Use Enums");
-    qmlRegisterUncreatableType<KCalendarCore::Attendee>("org.kde.calindori", 0, 1, "CalendarAttendee", "Use Enums");
+    qmlRegisterUncreatableType<KCalendarCore::Incidence>("org.kde.calindori", 0, 1, "CalendarIncidence", QStringLiteral("Use Enums"));
+    qmlRegisterUncreatableType<KCalendarCore::Attendee>("org.kde.calindori", 0, 1, "CalendarAttendee", QStringLiteral("Use Enums"));
 
     qmlRegisterSingletonType<DataHandler>("org.kde.calindori", 0, 1, "DataHandler", [](QQmlEngine * engine, QJSEngine *) -> QObject* {
         auto instance = DataHandler::instance();
@@ -106,18 +107,10 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         return instance;
     });
 
-    static CalendarController *s_calendar_controller = nullptr;
-    qmlRegisterSingletonType<CalendarController>("org.kde.calindori", 0, 1, "CalendarController", [](QQmlEngine * engine, QJSEngine *) -> QObject* {
-        engine->setObjectOwnership(s_calendar_controller, QQmlEngine::CppOwnership);
-
-        return s_calendar_controller;
-    });
-
-    CalendarController calendarController;
-    s_calendar_controller = &calendarController;
+    qmlRegisterSingletonInstance("org.kde.calindori", 0, 1, "CalindoriConfig", &CalindoriConfig::instance());
+    qmlRegisterSingletonInstance("org.kde.calindori", 0, 1, "CalendarController", &CalendarController::instance());
 
     DataHandler dataHandler;
-    dataHandler.setCalendarController(&calendarController);
 
 #ifndef Q_OS_ANDROID
     QObject::connect(&service, &KDBusService::activateRequested, [&parser, &dataHandler](const QStringList & args, const QString & workingDir) {
@@ -139,9 +132,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     ReccurencePeriodModel repeatModel;
     engine.rootContext()->setContextProperty(QStringLiteral("_repeatModel"), &repeatModel);
 
-    CalindoriConfig calindoriConfig;
-    engine.rootContext()->setContextProperty(QStringLiteral("_calindoriConfig"), &calindoriConfig);
-
     engine.rootContext()->setContextProperty(QStringLiteral("_aboutData"), QVariant::fromValue(aboutData));
     engine.rootContext()->setContextProperty(QStringLiteral("_appLocale"), QLocale::system());
 
